@@ -49,6 +49,8 @@
 
 #include <zeep/json/element.hpp>
 
+#include "revision.hpp"
+
 #ifdef _MSC_VER
 //MSVC stdlib.h definitions
 #define STDIN_FILENO 0
@@ -60,8 +62,6 @@ namespace po = boost::program_options;
 namespace fs = std::filesystem;
 namespace ba = boost::algorithm;
 
-std::string VERSION_STRING;
-
 using mmcif::Atom;
 using mmcif::Point;
 using mmcif::Structure;
@@ -797,7 +797,7 @@ const Data& DataTable::loadRamachandranData(const std::string& aa, SecStrType ss
 			break;
 	}
 
-	if (i == m_torsion.end())
+	if (i == m_ramachandran.end())
 		throw std::runtime_error("Data missing for aa= " + aa + " and ss = '" + static_cast<char>(ss) + '\'');
 	
 	return *i;
@@ -918,13 +918,26 @@ json calculateZScores(const Structure& structure)
 
 				aa = "PRO";
 			}
+			else if (aa == "ASX")
+			{
+				if (cif::VERBOSE > 1)
+					std::cerr << "Replacing ASX with ASP" << std::endl;
 
-			if (mmcif::kAAMap.find(aa) == mmcif::kAAMap.end())
+				aa = "ASP";
+			}
+			else if (aa == "GLX")
+			{
+				if (cif::VERBOSE > 1)
+					std::cerr << "Replacing GLX with GLU" << std::endl;
+
+				aa = "GLU";
+			}
+			else if (mmcif::kAAMap.find(aa) == mmcif::kAAMap.end())
 			{
 				if (cif::VERBOSE)
-					std::cerr << "Skipping unrecognized residue " << aa << std::endl;
+					std::cerr << "Replacing " << aa << " with ALA" << std::endl;
 
-				continue;
+				aa = "ALA";
 			}
 			
 			SecStrType tors_ss, rama_ss;
@@ -943,6 +956,7 @@ json calculateZScores(const Structure& structure)
 			else
 				rama_ss = tors_ss;
 
+#pragma warning "todo"
 			auto& rd = tbl.loadRamachandranData(aa, rama_ss);
 
 			auto zr = rd.zscore(phi, psi);
@@ -1066,7 +1080,7 @@ class tortoize_rest_controller : public zeep::http::rest_controller
 				{ "software",
 					{
 						{ "name", "tortoize" },
-						{ "version", VERSION_STRING },
+						{ "version", kVersionNumber },
 						{ "reference", "Sobolev et al. A Global Ramachandran Score Identifies Protein Structures with Unlikely Stereochemistry, Structure (2020)" },
 						{ "reference-doi", "https://doi.org/10.1016/j.str.2020.08.005" }
 					}
@@ -1267,7 +1281,7 @@ int pr_main(int argc, char* argv[])
 
 	if (vm.count("version"))
 	{
-		std::cout << argv[0] << " version " << VERSION_STRING << std::endl;
+		write_version_string(std::cout, vm.count("verbose"));
 		exit(0);
 	}
 
@@ -1347,7 +1361,7 @@ References:
 		{ "software",
 			{
 				{ "name", "tortoize" },
-				{ "version", VERSION_STRING },
+				{ "version", kVersionNumber },
 				{ "reference", "Sobolev et al. A Global Ramachandran Score Identifies Protein Structures with Unlikely Stereochemistry, Structure (2020)" },
 				{ "reference-doi", "https://doi.org/10.1016/j.str.2020.08.005" }
 			}
@@ -1393,71 +1407,6 @@ References:
 
 // --------------------------------------------------------------------
 
-namespace {
-	std::string gVersionNr, gVersionDate;
-}
-
-void load_version_info()
-{
-	const std::regex
-		rxVersionNr(R"(build-(\d+)-g[0-9a-f]{7}(-dirty)?)"),
-		rxVersionDate(R"(Date: +(\d{4}-\d{2}-\d{2}).*)"),
-		rxVersionNr2(R"(tortoize-version: (\d+(?:\.\d+)+))");
-
-#include "revision.hpp"
-
-	struct membuf : public std::streambuf
-	{
-		membuf(char* data, size_t length)       { this->setg(data, data, data + length); }
-	} buffer(const_cast<char*>(kRevision), sizeof(kRevision));
-
-	std::istream is(&buffer);
-
-	std::string line;
-
-	while (getline(is, line))
-	{
-		std::smatch m;
-
-		if (std::regex_match(line, m, rxVersionNr))
-		{
-			gVersionNr = m[1];
-			if (m[2].matched)
-				gVersionNr += '*';
-			continue;
-		}
-
-		if (std::regex_match(line, m, rxVersionDate))
-		{
-			gVersionDate = m[1];
-			continue;
-		}
-
-		// always the first, replace with more specific if followed by the other info
-		if (std::regex_match(line, m, rxVersionNr2))
-		{
-			gVersionNr = m[1];
-			continue;
-		}
-	}
-
-	if (not VERSION_STRING.empty())
-		VERSION_STRING += "\n";
-	VERSION_STRING += gVersionNr + " " + gVersionDate;
-}
-
-std::string get_version_nr()
-{
-	return gVersionNr/* + '/' + cif::get_version_nr()*/;
-}
-
-std::string get_version_date()
-{
-	return gVersionDate;
-}
-
-// --------------------------------------------------------------------
-
 // recursively print exception whats:
 void print_what (const std::exception& e)
 {
@@ -1473,14 +1422,14 @@ void print_what (const std::exception& e)
 	}
 }
 
+#if not defined(TORTOIZE_TEST_NO_MAIN)
+
 int main(int argc, char* argv[])
 {
 	int result = -1;
 	
 	try
 	{
-		load_version_info();
-		
 		result = pr_main(argc, argv);
 	}
 	catch (std::exception& ex)
@@ -1492,3 +1441,4 @@ int main(int argc, char* argv[])
 	return result;
 }
 
+#endif
\ No newline at end of file
